/* ==================
 * Wrench 8 and 11 mm
 * ==================
 * Version 24 July 2022
 *
 * Wrench for SMA (8mm) and FME (11 mm) coaxial connectors
 */

z_size			= 6;
slack			= 0.15;
centers_spacing	= 50;

wrench();

module wrench() {
	translate([-centers_spacing/2,0,0]) forkhead(8);
	handle(centers_spacing-8,10,z_size);
	translate([+centers_spacing/2,0,0]) rotate([0,0,180]) forkhead(11);
}

module forkhead(opening_size) {
	faktor = 0.57;
	difference() {
		// Forkhead outer contour
		cylinder(r=(opening_size*2)/2,h=z_size,$fn=72,center=true);
		// Jaw
		rotate([0,0,200]) translate([opening_size/2,0,0]) {
			cylinder(r=faktor*opening_size+slack,h=z_size+2,$fn=6,center=true);
			translate([opening_size/2,0,]) cube([opening_size,opening_size+2*slack,z_size+1],true);
		}
	}
	// Label
	translate([+opening_size,0,0]) linear_extrude(height=z_size/2+1,convexity=10) text(str(opening_size),halign="left",valign="center",size=8);
	// Test
//	color("MAGENTA") rotate([0,0,200]) translate([opening_size/2,0,0]) cylinder(r=faktor*opening_size,h=z_size+1,$fn=6,center=true);
}

module handle(length,width,z_size) {
	cube([length,width,z_size],true);
}
